==> jinkies-0.2.5.tgz: package/lib/robot.js <==
(function() {
  var Build, Campfire, CampfireRobot, EventEmitter, HttpRequest, Job, Robot;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  Campfire = require("jenkins/utils/campfire").Campfire;
  HttpRequest = require("jenkins/utils/http_request").HttpRequest;
  EventEmitter = require("events").EventEmitter;
  Build = (function() {
    function Build(job, number) {
      this.job = job;
      this.number = number;
    }
    Build.prototype.info = function(callback) {
      return this.job.client.fetch("/jobs/" + this.job.name + "/builds/" + this.number, function(err, data) {
        return callback(err, data);
      });
    };
    Build.prototype.notify = function(callback) {
      var self;
      self = this;
      return this.info(function(err, data) {
        var branch, compare, duration, number, reply, sha;
        sha = data.sha1.slice(0, 7);
        number = data.number;
        branch = data.branch;
        reply = "Build #" + number + " (" + sha + ") of " + self.job.name + "/" + branch;
        compare = data.payload && data.payload.compare;
        duration = data.data.duration / 1000 || 0.0;
        switch (data.status) {
          case "successful":
            reply += " was successful ";
            break;
          case "failed":
            reply += " failed ";
            break;
          case "building":
            reply += " building now ";
            break;
          default:
            reply += " unknown[" + data.status + "] ";
        }
        self.status = data.status;
        reply += "(" + (Math.floor(duration)) + "s).";
        if (compare) {
          reply += " " + compare;
        }
        return callback(err, self, reply, data.consoleText);
      });
    };
    return Build;
  })();
  Job = (function() {
    function Job(client, name) {
      this.client = client;
      this.name = name;
      this.number = 1;
    }
    Job.prototype.poll = function(callback) {
      var self;
      self = this;
      return this.client.fetch("/jobs/" + this.name, function(err, data) {
        var build;
        if (data.lastCompletedBuild.number > self.number) {
          self.number = data.lastCompletedBuild.number;
          build = new Build(self, self.number);
          build.notify(function(err, build, notification, output) {
            return callback(err, build, notification, output);
          });
        }
        return setTimeout((function() {
          return self.poll(callback);
        }), 15000);
      });
    };
    return Job;
  })();
  Robot = (function() {
    __extends(Robot, EventEmitter);
    function Robot(host) {
      this.host = host;
      this.client = new HttpRequest(this.host);
    }
    Robot.prototype.findJobs = function(callback) {
      var client;
      client = this.client;
      return client.fetch("/jobs", function(err, data) {
        var job, _i, _len, _results;
        _results = [];
        for (_i = 0, _len = data.length; _i < _len; _i++) {
          job = data[_i];
          _results.push((function(job) {
            return callback(err, new Job(client, job.name));
          })(job));
        }
        return _results;
      });
    };
    Robot.prototype.run = function(callback) {
      var self;
      self = this;
      return this.findJobs(function(err, job) {
        return job.poll(function(err, build, notification, output) {
          return self.emit("build", err, build, notification, output);
        });
      });
    };
    return Robot;
  })();
  CampfireRobot = (function() {
    function CampfireRobot(host, options) {
      this.host = host;
      this.options = options;
      this.robot = new Robot(this.host);
      this.campfire = new Campfire(this.options);
      this.room = this.campfire.Room(this.options.room);
    }
    CampfireRobot.prototype.run = function() {
      var room;
      room = this.room;
      this.robot.on("build", function(err, build, notification, output) {
        return room.speak(notification, function(err, data) {
          console.log("Sent: " + notification);
          if (build.status === "failed") {
            return room.paste(output, function(err, data) {
              return console.log("Pasted failures");
            });
          }
        });
      });
      return this.robot.run();
    };
    return CampfireRobot;
  })();
  exports.Robot = Robot;
  exports.CampfireRobot = CampfireRobot;
}).call(this);

==> jinkies-0.2.11.tgz: package/lib/robot.js <==
(function() {
  var Build, Campfire, CampfireRobot, EventEmitter, HttpRequest, Job, Robot;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  Campfire = require("jenkins/utils/campfire").Campfire;
  HttpRequest = require("jenkins/utils/http_request").HttpRequest;
  EventEmitter = require("events").EventEmitter;
  Build = (function() {
    function Build(job, number) {
      this.job = job;
      this.number = number;
    }
    Build.prototype.info = function(callback) {
      return this.job.client.fetch("/jobs/" + this.job.name + "/builds/" + this.number, function(err, data) {
        return callback(err, data);
      });
    };
    Build.prototype.notify = function(callback) {
      var self;
      self = this;
      return this.info(function(err, data) {
        var branch, compare, duration, number, reply, sha;
        sha = data.sha1.slice(0, 7);
        number = data.number;
        branch = data.branch;
        reply = "Build #" + number + " (" + sha + ") of " + self.job.name + "/" + branch;
        compare = data.payload && data.payload.compare;
        duration = data.data.duration / 1000 || 0.0;
        switch (data.status) {
          case "successful":
            reply += " was successful ";
            break;
          case "failed":
            reply += " failed ";
            break;
          case "building":
            reply += " building now ";
            break;
          default:
            reply += " unknown[" + data.status + "] ";
        }
        self.status = data.status;
        reply += "(" + (Math.floor(duration)) + "s).";
        if (compare) {
          reply += " " + compare;
        }
        return callback(err, self, reply, data.consoleText);
      });
    };
    return Build;
  })();
  Job = (function() {
    function Job(client, name) {
      this.client = client;
      this.name = name;
      this.number = null;
    }
    Job.prototype.poll = function(callback) {
      var self;
      self = this;
      return this.client.fetch("/jobs/" + this.name, function(err, data) {
        var build, prev_number;
        if (!self.number || data.lastCompletedBuild.number > self.number) {
          prev_number = self.number;
          self.number = data.lastCompletedBuild.number;
          if (prev_number != null) {
            build = new Build(self, self.number);
            build.notify(function(err, build, notification, output) {
              return callback(err, build, notification, output);
            });
          }
        }
        return setTimeout((function() {
          return self.poll(callback);
        }), 15000);
      });
    };
    return Job;
  })();
  Robot = (function() {
    __extends(Robot, EventEmitter);
    function Robot(host) {
      this.host = host;
      this.client = new HttpRequest(this.host);
    }
    Robot.prototype.findJobs = function(callback) {
      var client;
      client = this.client;
      return client.fetch("/jobs", function(err, data) {
        var job, _i, _len, _results;
        _results = [];
        for (_i = 0, _len = data.length; _i < _len; _i++) {
          job = data[_i];
          _results.push((function(job) {
            return callback(err, new Job(client, job.name));
          })(job));
        }
        return _results;
      });
    };
    Robot.prototype.run = function(callback) {
      var self;
      self = this;
      return this.findJobs(function(err, job) {
        return job.poll(function(err, build, notification, output) {
          return self.emit("build", err, build, notification, output);
        });
      });
    };
    return Robot;
  })();
  CampfireRobot = (function() {
    function CampfireRobot(host, options) {
      this.host = host;
      this.options = options;
      this.robot = new Robot(this.host);
      this.campfire = new Campfire(this.options);
      this.room = this.campfire.Room(this.options.room);
    }
    CampfireRobot.prototype.run = function() {
      var room;
      room = this.room;
      this.robot.on("build", function(err, build, notification, output) {
        return room.speak(notification, function(err, data) {
          console.log("Sent: " + notification);
          if (build.status === "failed") {
            return room.paste(output, function(err, data) {
              return console.log("Pasted failures");
            });
          }
        });
      });
      return this.robot.run();
    };
    return CampfireRobot;
  })();
  exports.Robot = Robot;
  exports.CampfireRobot = CampfireRobot;
}).call(this);
